@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Stef Walter <stefw@collabora.co.uk>
  */
@@ -48,7 +46,7 @@ egg_testing_on_valgrind (void)
 #ifdef WITH_VALGRIND
 	return RUNNING_ON_VALGRIND;
 #else
-	return FALSE
+	return FALSE;
 #endif
 }
 
