@@ -12,9 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -1129,7 +1127,7 @@ _gcr_display_view_append_message (GcrDisplayView *self,
                                   GtkMessageType message_type,
                                   const gchar *message)
 {
-	const gchar *stock_id = NULL;
+	const gchar *name = NULL;
 	GtkWidget *image = NULL;
 	GcrDisplayItem *item;
 	GtkTextChildAnchor *anchor;
@@ -1143,19 +1141,19 @@ _gcr_display_view_append_message (GcrDisplayView *self,
 
 	switch (message_type) {
 	case GTK_MESSAGE_INFO:
-		stock_id = GTK_STOCK_DIALOG_INFO;
+		name = "dialog-information";
 		break;
 
 	case GTK_MESSAGE_QUESTION:
-		stock_id = GTK_STOCK_DIALOG_QUESTION;
+		name = "dialog-question";
 		break;
 
 	case GTK_MESSAGE_WARNING:
-		stock_id = GTK_STOCK_DIALOG_WARNING;
+		name = "dialog-warning";
 		break;
 
 	case GTK_MESSAGE_ERROR:
-		stock_id = GTK_STOCK_DIALOG_ERROR;
+		name = "dialog-error";
 		break;
 
 	case GTK_MESSAGE_OTHER:
@@ -1168,8 +1166,8 @@ _gcr_display_view_append_message (GcrDisplayView *self,
 
 	gtk_text_buffer_get_iter_at_mark (self->pv->buffer, &iter, item->ending);
 
-	if (stock_id != NULL) {
-		image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_MENU);
+	if (name != NULL) {
+		image = gtk_image_new_from_icon_name (name, GTK_ICON_SIZE_MENU);
 		gtk_misc_set_padding (GTK_MISC (image), MESSAGE_PADDING, 0);
 		gtk_widget_show (image);
 
@@ -1189,7 +1187,6 @@ _gcr_display_view_set_icon (GcrDisplayView *self, GcrRenderer *renderer, GIcon *
 	GcrDisplayItem *item;
 	GdkScreen *screen;
 	GtkIconTheme *icon_theme;
-	GtkSettings *settings;
 	gint width, height;
 	GtkIconInfo *info;
 
@@ -1206,9 +1203,8 @@ _gcr_display_view_set_icon (GcrDisplayView *self, GcrRenderer *renderer, GIcon *
 
 	screen = gtk_widget_get_screen (GTK_WIDGET (self));
 	icon_theme = gtk_icon_theme_get_for_screen (screen);
-	settings = gtk_settings_get_for_screen (screen);
 
-	if (!gtk_icon_size_lookup_for_settings (settings, GTK_ICON_SIZE_DIALOG, &width, &height))
+	if (!gtk_icon_size_lookup (GTK_ICON_SIZE_DIALOG, &width, &height))
 		g_return_if_reached ();
 
 	info = gtk_icon_theme_lookup_by_gicon (icon_theme, icon, MIN (width, height),
